@@ -63,18 +63,18 @@ class Connector(APIResource):
         return cls.s3_client  # , cls.credentials['bucket'], cls.credentials['path']
 
     @classmethod
-    def read_to_pandas_df(cls, user_token: str = None):  # s3_client, bucket, path):
+    def read_to_pandas_df(cls, file_name: str, user_token: str = None):
         cls.get_s3_boto_client(user_token=user_token)
-        obj = cls.s3_client.get_object(Bucket=cls.credentials['bucket'], Key=cls.credentials['path'])
+        obj = cls.s3_client.get_object(Bucket=cls.credentials['bucket'], Key='/'.join([cls.credentials['path'], file_name]))
         df = pd.read_csv(obj['Body'])
         return df
 
     @classmethod
-    def write_pandas_df_to_s3(cls, df, user_token: str = None): # s3_client, bucket, path, df):
+    def write_pandas_df_to_s3(cls, df, file_name: str, user_token: str = None):
         s3_client = cls.get_s3_boto_client(user_token=user_token)
         csv_buffer = StringIO()
         df.to_csv(csv_buffer)
-        s3_client.upload_fileobj(csv_buffer, Bucket=cls.credentials['bucket'], Key=cls.credentials['path'])
+        s3_client.upload_fileobj(csv_buffer, Bucket=cls.credentials['bucket'], Key='/'.join([cls.credentials['path'], file_name]))
 
 
 
