@@ -318,62 +318,6 @@ class MyWhatify:
             task_id = my_toolkit.Task.get_task_id(task_name=task_name)
             return my_toolkit.Ensemble.get_ensemble_id(task_id=task_id)
 
-    @classmethod
-    def get_data_file(cls, data_name='car_sdk_demo.csv'):
-        with allure.step('getting csv from data file for data_name: ' + str(data_name)):
-            script_dir = os.path.dirname(__file__)
-            path = os.path.join(script_dir, '../data_source/')
-            # path = "https://raw.githubusercontent.com/NeuralAlgorithms/firefly-python-sdk/master/examples/"
-        return pd.read_csv(path + data_name)
-
-    @classmethod
-    def get_created_data_file(cls, data_name='temp.csv'):
-        df_data = cls.get_data_file(data_name='car_sdk_demo_test_no.csv')
-        data = df_data.get_values()
-        script_dir = os.path.dirname(__file__)
-        path = os.path.join(script_dir, '../data_source/') + data_name
-        with open(path, 'a') as f:
-            f.write('car_id,buying,maint,doors,persons,lug_boot,junk_feature,safety')
-            for i in range(1):
-                for row in data:
-                    text = ''
-                    for index in range(row.__len__()):
-                        text += str(row.tolist().pop(index)) + ","
-                    f.write('\n' + text[:-1])
-            f.close()
-
-    @classmethod
-    def get_data_file_s3(cls, data_name='car_sdk_demo.csv'):
-        logging.info('getting csv from data file for data_name: ' + str(data_name))
-        script_dir = os.path.dirname(__file__)
-        path = os.path.join(script_dir, '../data_source/')
-        path = "s3://firefly-automation/whatify_demo/"
-        # path = "https://raw.githubusercontent.com/NeuralAlgorithms/firefly-python-sdk/master/examples/"
-        return pd.read_csv(path + data_name)
-
-    @classmethod
-    def ls_client(cls, user_token: str = None):
-        return my_toolkit.Connector.get_client_path(user_token=user_token)
-
-    @classmethod
-    def get_credentials(cls, api_key: str = None):
-        retval = my_toolkit.Connector.get_credentials(user_token=api_key)
-        return retval
-
-    @classmethod
-    def get_s3_path(cls, user_token: str = None):
-        return my_toolkit.Connector.get_s3_path(user_token=user_token)
-
-    @classmethod
-    def read_to_pandas_df(cls, user_token: str = None):
-        df = my_toolkit.Connector.read_to_pandas_df(user_token=user_token)
-        print('dele')
-        return df
-
-    @classmethod
-    def write_pandas_df_to_s3(cls, df, user_token: str = None):  # s3_client, bucket, path, df):
-        my_toolkit.Connector.write_pandas_df_to_s3(df=df, user_token=user_token)
-
     @classmethod
     def get_pipeline_list(cls, dataset_id, interpt_level=Interpt.PRECISE):
         return cls.get_pipeline_estimators_list(dataset_id, True, interpt_level)
@@ -441,6 +385,69 @@ class MyWhatify:
     #             pass
     #     print('dddd')
 
+    #############################
+    ###       Connector       ###
+    #############################
+
+    @classmethod
+    def ls_client(cls, user_token: str = None):
+        return my_toolkit.Connector.get_client_path(user_token=user_token)
+
+    @classmethod
+    def get_credentials(cls, api_key: str = None):
+        retval = my_toolkit.Connector.get_credentials(user_token=api_key)
+        return retval
+
+    @classmethod
+    def get_s3_path(cls, user_token: str = None):
+        return my_toolkit.Connector.get_s3_path(user_token=user_token)
+
+    @classmethod
+    def read_to_pandas_df(cls, file_name: str, user_token: str = None):
+        return my_toolkit.Connector.read_to_pandas_df(file_name=file_name, user_token=user_token)
+
+    @classmethod
+    def write_pandas_df_to_s3(cls, df, file_name: str, user_token: str = None):  # s3_client, bucket, path, df):
+        return my_toolkit.Connector.write_pandas_df_to_s3(df=df, user_token=user_token)
+
+    #############################
+    ###       data_file       ###
+    #############################
+
+    @classmethod
+    def get_data_file_s3(cls, data_name='car_sdk_demo.csv'):
+        logging.info('getting csv from data file for data_name: ' + str(data_name))
+        script_dir = os.path.dirname(__file__)
+        path = os.path.join(script_dir, '../data_source/')
+        path = "s3://firefly-automation/whatify_demo/"
+        # path = "https://raw.githubusercontent.com/NeuralAlgorithms/firefly-python-sdk/master/examples/"
+        return pd.read_csv(path + data_name)
+
+    @classmethod
+    def get_data_file(cls, data_name='car_sdk_demo.csv'):
+        with allure.step('getting csv from data file for data_name: ' + str(data_name)):
+            script_dir = os.path.dirname(__file__)
+            path = os.path.join(script_dir, '../data_source/')
+            # path = "https://raw.githubusercontent.com/NeuralAlgorithms/firefly-python-sdk/master/examples/"
+        return pd.read_csv(path + data_name)
+
+    @classmethod
+    def get_created_data_file(cls, data_name='temp.csv'):
+        df_data = cls.get_data_file(data_name='car_sdk_demo_test_no.csv')
+        data = df_data.get_values()
+        script_dir = os.path.dirname(__file__)
+        path = os.path.join(script_dir, '../data_source/') + data_name
+        with open(path, 'a') as f:
+            f.write('car_id,buying,maint,doors,persons,lug_boot,junk_feature,safety')
+            for i in range(1):
+                for row in data:
+                    text = ''
+                    for index in range(row.__len__()):
+                        text += str(row.tolist().pop(index)) + ","
+                    f.write('\n' + text[:-1])
+            f.close()
+
     #############################
     ###      Validation       ###
     #############################
+
